import argparse
import csv
import os
import shutil
import sys


def get_pkg_names_from_csv(csv_filepath):
    """
    Retrieves package names from a CSV file.

    Args:
    - csv_filepath (str): Path to the CSV file containing package names.

    Returns:
    - list: List of unique package names extracted from the CSV file.
    """
    pkg_names = set()
    with open(csv_filepath, mode='rb') as csvfile:
        reader = csv.reader(csvfile, delimiter=',')
        for row in reader:
            pkg_names.add(row[0])
    return list(pkg_names)


def get_pkg_names_from_src_dir(src_dir):
    """
    Retrieves package names from a source directory.

    Args:
    - src_dir (str): Path to the source directory containing package directories.

    Returns:
    - list: List of unique package names found in the source directory.
    """
    pkg_names = set()
    for filename in os.listdir(src_dir):
        pkg_name = os.path.basename(filename)
        pkg_names.add(pkg_name)
    return list(pkg_names)


def remove_directory(directory_path):
    """
    Removes a directory and all its contents.

    Args:
    - directory_path (str): Path to the directory to be removed.
    """
    try:
        if os.path.exists(directory_path):
            shutil.rmtree(directory_path)
            print 'Deleted \'{}\' directory.'.format(directory_path)
    except Exception as e:
        print 'Error: {} : {}'.format(directory_path, e)


def main():
    """
    Main function to execute the script.
    """
    parser = argparse.ArgumentParser(description='Remove invalid git source repositories')
    parser.add_argument('-s', '--source_dir', help='Path to the source directory', required=True)
    parser.add_argument('-i', '--csv_filepath', help='Path to the CSV file to read the source information',
                        required=True)
    args = parser.parse_args()

    if not os.path.isfile(args.csv_filepath):
        print '{} does not exist'.format(args.csv_filepath)
        sys.exit(1)

    if not os.path.isdir(args.source_dir):
        print '{} is not a directory or does not exist'.format(args.source_dir)
        sys.exit(1)

    csv_pkg_names = get_pkg_names_from_csv(args.csv_filepath)
    src_pkg_names = get_pkg_names_from_src_dir(args.source_dir)

    for pkg in src_pkg_names:
        if pkg not in csv_pkg_names:
            print 'Package \'{}\' does not exist in the CSV file'.format(pkg)
            src_dir = os.path.join(args.source_dir, pkg)
            remove_directory(src_dir)


if __name__ == '__main__':
    main()



import ConfigParser
import argparse
import csv
import json
import os
import re
import sys

DOMAIN = ''
GROUP_ID = ''


def parse_git_url(url_string):
    """
    Parse a git URL to extract the domain, group, repository name, and branch.

    :param url_string: str - The git URL to parse.
    :return: dict or None - Dictionary with parsed components or None if the URL doesn't match the pattern.
    """
    global DOMAIN
    global GROUP_ID
    pattern = (r"git@(?P<domain>[\w\.]+):(?P<group_id>[\w\-]+)/(?P<repo_name>[^/\.]+[\w\.-]*)\.git"
               r"\s+branch=(?P<branch>[^\s]+)")
    match = re.search(pattern, url_string)
    if match:
        DOMAIN = match.group('domain')
        GROUP_ID = match.group('group_id')
        return {'domain': match.group('domain'),
                'group_id': match.group('group_id'),
                'repo_name': match.group('repo_name'),
                'branch': match.group('branch')}
    return None


def get_src_branches(rcfg_filepaths):
    """
    Extract source branches from release configuration files.

    :param rcfg_filepaths: list - List of file paths to release configuration files.
    :return: dict - Dictionary of repository names to branch information.
    """
    src_branches = {}
    for rcfg_filepath in rcfg_filepaths:
        config = ConfigParser.ConfigParser()
        config.optionxform = str
        config.read(rcfg_filepath)
        if config.has_section('sources'):
            for key, value in config.items('sources'):
                repo_name = key.strip().replace('-', '_')
                if repo_name.endswith('.etl'):
                    continue
                url_info = parse_git_url(value.strip())
                if url_info:
                    src_branches[repo_name] = url_info
    return src_branches


def get_src_tags(vcfg_filepaths):
    """
    Extract source tags from version configuration files.

    :param vcfg_filepaths: list - List of file paths to version configuration files.
    :return: dict - Dictionary of repository names to tag information.
    """
    src_tags = {}
    for vcfg_filepath in vcfg_filepaths:
        config = ConfigParser.ConfigParser()
        config.optionxform = str
        config.read(vcfg_filepath)
        if config.has_section('versions'):
            for key, value in config.items('versions'):
                repo_name = key.strip().replace('-', '_')
                if repo_name.endswith('.etl'):
                    continue
                src_tags[repo_name] = {'tag': 'v{}'.format(value.strip())}
    return src_tags


def write_to_csv(csv_filepath, data_dict):
    """
    Write repository information to a CSV file.

    :param csv_filepath: str - File path to the CSV file.
    :param data_dict: dict - Dictionary containing repository information.
    """
    with open(csv_filepath, mode='wb') as csvfile:
        writer = csv.writer(csvfile, delimiter=',')
        for key, value in data_dict.items():
            writer.writerow([key, value['group_id'], value['ssh_url'], value['branch']])


def get_git_src_info(product_rcfg, custom_rcfg, product_vcfg, custom_vcfg, extra_sources, exclude_sources, pattern):
    """
    Obtain source information for git repositories based on configuration files and additional sources.

    :param product_rcfg: str - Path to the product's release.cfg file.
    :param custom_rcfg: str - Path to the custom release.cfg file.
    :param product_vcfg: str - Path to the product's versions.cfg file.
    :param custom_vcfg: str - Path to the custom versions.cfg file.
    :param extra_sources: str - Additional source information in the format "user_id:name:branch".
    :param exclude_sources: str - Excluded source information (comma separated).
    :param pattern: str - Regex pattern to filter repositories.
    :return: dict - Dictionary with source information.
    """
    domain = ''
    compiled_pattern = re.compile(pattern)
    rcfg_filepaths = [product_rcfg, custom_rcfg]
    vcfg_filepaths = [product_vcfg, custom_vcfg]

    rinfo = get_src_branches(rcfg_filepaths)
    vinfo = get_src_tags(vcfg_filepaths)

    src_dict = {}
    for key, value in vinfo.items():
        if compiled_pattern.match(key):
            if key in rinfo:
                domain = rinfo[key]['domain']
                group_id = rinfo[key]['group_id']
            else:
                domain = DOMAIN
                group_id = GROUP_ID
            ssh_url = 'git@{}:{}/{}.git'.format(domain, group_id, key)
            src_dict[key] = {'group_id': group_id, 'ssh_url': ssh_url,
                             'branch': value['tag'], 'is_tag': True}

    crinfo = get_src_branches([custom_rcfg])
    for key, value in crinfo.items():
        if compiled_pattern.match(key):
            domain = value['domain']
            group_id = value['group_id']
            branch = value['branch']
            ssh_url = 'git@{}:{}/{}.git'.format(domain, group_id, key)
            src_dict[key] = {'group_id': group_id, 'ssh_url': ssh_url,
                             'branch': branch, 'is_tag': False}

    if extra_sources:
        for each in extra_sources.split('|'):
            group_id, name, branch = each.split(':')
            ssh_url = 'git@{}:{}/{}.git'.format(domain, group_id, name)
            src_dict[name] = {'group_id': group_id, 'ssh_url': ssh_url, 'branch': branch,
                              'is_tag': True if branch.startswith('v') else False}
    if exclude_sources:
        for each in exclude_sources.split(','):
            if each in src_dict:
                del src_dict[each]

    return {'count': len(src_dict.keys()), 'data': src_dict}


def main():
    """
    Main function to parse arguments and obtain git repositories source information.

    :return: None
    """
    parser = argparse.ArgumentParser(description='Obtain source information for git repositories')
    parser.add_argument('-pr', '--product_rcfg', help='Path to the product release.cfg file', required=True)
    parser.add_argument('-cr', '--custom_rcfg', help='Path to the custom release.cfg file', required=True)
    parser.add_argument('-pv', '--product_vcfg', help='Path to the product versions.cfg file', required=True)
    parser.add_argument('-cv', '--custom_vcfg', help='Path to the custom versions.cfg file', required=True)
    parser.add_argument('-e', '--extra_sources', help='Extra source information in the format "user_id:name:branch"')
    parser.add_argument('-x', '--exclude_sources', help='Sources to exclude from list (comma separated)')
    parser.add_argument('-o', '--csv_filepath', help='Path to the CSV file to write the source information')
    parser.add_argument('-p', '--pattern', help='Regex pattern to filter the repositories', required=True)
    parser.add_argument('-j', '--json', action='store_true', help='Output the source information in JSON format')
    args = parser.parse_args()

    for file_arg in [args.product_rcfg, args.custom_rcfg, args.product_vcfg, args.custom_vcfg]:
        if not os.path.isfile(file_arg):
            print '{} does not exist'.format(file_arg)
            sys.exit(1)

    src_info = get_git_src_info(product_rcfg=args.product_rcfg, custom_rcfg=args.custom_rcfg,
                                product_vcfg=args.product_vcfg, custom_vcfg=args.custom_vcfg,
                                extra_sources=args.extra_sources, pattern=args.pattern,
                                exclude_sources=args.exclude_sources)

    if args.csv_filepath:
        write_to_csv(csv_filepath=args.csv_filepath, data_dict=src_info['data'])

    if args.json:
        print json.dumps(src_info, indent=4, sort_keys=True)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cktools_jenkins']

package_data = \
{'': ['*'], 'cktools_jenkins': ['templates/*']}

entry_points = \
{'console_scripts': ['ckgitinfo = cktools_jenkins.git_src_info_extractor:main',
                     'ckmail = cktools_jenkins.send_email:main']}

setup_kwargs = {
    'name': 'cktools-jenkins',
    'version': '0.2.6',
    'description': 'Tools for Jenkins',
    'long_description': '# CKTools-Jenkins v0.2.6',
    'author': 'Chandan Kumar',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=2.7,<3.0',
}


setup(**setup_kwargs)



import argparse
import os
import smtplib
from email import Encoders
from string import Template

from email.mime.base import MIMEBase
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText


def send_email(smtp_server, from_addr, to_addr_list, cc_addr_list, subject, message, attachment_path):
    """
    Sends an email using the specified SMTP server.

    :param smtp_server: str - The SMTP server address used to send the email.
    :param from_addr: str - The email address of the sender.
    :param to_addr_list: list - A list of email addresses to send the email to.
    :param cc_addr_list: list - A list of email addresses to CC.
    :param subject: str - The subject line of the email.
    :param message: str - The body text of the email.
    :param attachment_path: str - The file path to an attachment (optional).

    :return: None
    """
    msg = MIMEMultipart()
    msg['From'] = from_addr
    msg['To'] = ', '.join(to_addr_list)
    msg['Cc'] = ', '.join(cc_addr_list)
    msg['Subject'] = subject

    msg.attach(MIMEText(message, 'html'))

    if attachment_path and os.path.isfile(attachment_path):
        part = MIMEBase('application', 'octet-stream')
        with open(attachment_path, 'rb') as f:
            part.set_payload(f.read())
        Encoders.encode_base64(part)
        part.add_header('Content-Disposition',
                        'attachment; filename="{}"'.format(os.path.basename(attachment_path)))
        msg.attach(part)

    try:
        server = smtplib.SMTP(smtp_server)
        to_addr_list = to_addr_list + cc_addr_list
        server.sendmail(from_addr, to_addr_list, msg.as_string())
        server.quit()
        print '[INFO] Email sent successfully.'
    except Exception as e:
        print '[ERROR] Failed to send email: {}'.format(e)


def get_template(tmpl_type, tmpl_data):
    """
    Returns the template content based on the type

    :param tmpl_type: str - Type of template ('pre' or 'post')
    :param tmpl_data: dict - Data to be used in the template
    :return: str - Template content
    """
    tmpl_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                             'templates', '{}_job.tmpl'.format(tmpl_type))
    if os.path.isfile(tmpl_path):
        with open(tmpl_path, 'r') as f:
            tmpl_obj = Template(f.read())
            return tmpl_obj.safe_substitute(**tmpl_data)
    return 'Template not found'


def main():
    """
    Main function

    :return: None
    """
    parser = argparse.ArgumentParser(description='Send Email')
    parser.add_argument('--host', help='SMTP server address', required=True)
    parser.add_argument('--from', dest='from_addr', help='Sender email address', required=True)
    parser.add_argument('--to', dest='to_addr', help='Recipient email addresses (comma-separated)', required=True)
    parser.add_argument('--cc', dest='cc_addr', help='CC email addresses (comma-separated)')
    parser.add_argument('--subject', help='Subject line of the email', required=True)
    parser.add_argument('--message', help='Body text of the email', default='No message body')
    parser.add_argument('--attachment', help='Path to an attachment file')
    parser.add_argument('--tmpl', choices=['pre', 'post'], help='Choose template to use')
    args = parser.parse_args()

    to_addr_list = args.to_addr.split(',')
    cc_addr_list = args.cc_addr.split(',') if args.cc_addr else []

    message = args.message
    if args.tmpl:
        tmpl_data_dict = {key: value for key, value in os.environ.items()}
        message = get_template(args.tmpl, tmpl_data_dict)

    send_email(smtp_server=args.host, from_addr=args.from_addr,
               to_addr_list=to_addr_list, cc_addr_list=cc_addr_list,
               subject=args.subject, message=message,
               attachment_path=args.attachment)


if __name__ == '__main__':
    main()
